Work in Progress
================

Here is a list of tasks we have slated for future releases (in rough
order of priority):

* Better error handling (send error to admin and send nice message to client)
* Enable better introspection of pending and completed work (admin)
* Enable bonus/surcharge for documents with excess text
* Improved handling of multiple assignments per page
* Browser support (IE8 has problems with upload form)
* Detailed instructions for new users
* Administrative notifications of new jobs
* Administrative notifications of errors
* Automatically approve submitted work
* E-mail results
* E-mail link to status
* Drag Drop
* update faq to mention language issues
* Job Naming (maybe use filename, maybe provide user-supplied field)
* Add new and pending features page
* Sanity checks on submitted work
* Quality Control review (additional cost)
* Rich text editor (google docs perhaps)
* Port to App Engine (or heroku)
* Support for non-standard documents

  * image extraction
  * standard forms
  * data sheets

* Privacy Enhancements
* Partial Page support
